@@ -4,6 +4,6 @@ from django.contrib.admin.views.decorators import staff_member_required
 from experiments.views import experiment_details, list_experiments
 
 urlpatterns = patterns('experiments.views',
-    url(r'^(?P<experiment_name>.+)/$', staff_member_required(experiment_details)),
-    url(r'^$', staff_member_required(list_experiments))
+    url(r'^(?P<experiment_name>.+)/$', staff_member_required(experiment_details), name="experiments_experiment_details"),
+    url(r'^$', staff_member_required(list_experiments), name="experiments_list_experiments")
 )
